@@ -44,6 +44,7 @@ class DQNAgent(AgentBase):
         """Initiates the DQN agent.
 
         Parameters:
+            hidden_layers: (default: (64, 64) ) Tuple defining hidden dimensions in fully connected nets.
             lr: (default: 1e-3) learning rate
             gamma: (default: 0.99) discount factor
             tau: (default: 0.002) soft-copy factor
@@ -60,7 +61,7 @@ class DQNAgent(AgentBase):
         super().__init__(**kwargs)
 
         self.device = self._register_param(kwargs, "device", DEVICE, update=True)
-        # TODO: All this should be condenced with some structure, e.g. gym spaces
+        # TODO: All this should be condensed with some structure, e.g. gym spaces
         self.input_shape: Sequence[int] = input_shape if not isinstance(input_shape, int) else (input_shape,)
         self.state_size: int = self.input_shape[0]
         self.output_shape: Sequence[int] = output_shape if not isinstance(output_shape, int) else (output_shape,)
@@ -133,7 +134,7 @@ class DQNAgent(AgentBase):
             state: S(t)
             action: A(t)
             reward: R(t)
-            nexxt_state: S(t+1)
+            next_state: S(t+1)
             done: (bool) Whether the state is terminal.
 
         """
